summaryrefslogtreecommitdiffabout
path: root/korganizer
Side-by-side diff
Diffstat (limited to 'korganizer') (more/less context) (ignore whitespace changes)
-rw-r--r--korganizer/koagenda.cpp31
-rw-r--r--korganizer/koagendaitem.cpp1
2 files changed, 30 insertions, 2 deletions
diff --git a/korganizer/koagendaitem.cpp b/korganizer/koagendaitem.cpp
index d0a7b07..38bd93a 100644
--- a/korganizer/koagendaitem.cpp
+++ b/korganizer/koagendaitem.cpp
@@ -135,6 +135,7 @@ void KOAgendaItem::init ( Incidence *incidence, QDate qd )
mBackgroundColor.dark(),mBackgroundColor, black, mBackgroundColor) ;
setBackgroundColor( mBackgroundColor );
+ mConflictItems.clear();
setCellXY(0,0,1);
setCellXWidth(0);
setSubCell(0);
diff --git a/korganizer/koagenda.cpp b/korganizer/koagenda.cpp
index a72e470..195b1fa 100644
--- a/korganizer/koagenda.cpp
+++ b/korganizer/koagenda.cpp
@@ -1079,7 +1079,7 @@ void KOAgenda::placeSubCells(KOAgendaItem *placeItem)
conflictItems.append(placeItem);
// Adjust sub cell geometry of all items
for ( item=conflictItems.first(); item != 0;
item=conflictItems.next() ) {
item->setSubCells(maxSubCells);
@@ -1099,7 +1099,34 @@ void KOAgenda::placeSubCells(KOAgendaItem *placeItem)
// qDebug("moveChild %s %d %d ", item->incidence()->summary().latin1() ,x,y);
//item->updateItem();
}
-
+ // Adjust sub cell geometry of all conflict items of all conflict items
+ for ( item=conflictItems.first(); item != 0;
+ item=conflictItems.next() ) {
+ if ( placeItem != item ) {
+ KOAgendaItem *item2;
+ QPtrList<KOAgendaItem> conflictItems2 = item->conflictItems();
+ for ( item2=conflictItems2.first(); item2 != 0;
+ item2=conflictItems2.next() ) {
+ if ( item2->subCells() != maxSubCells) {
+ item2->setSubCells(maxSubCells);
+ if (mAllDayMode) {
+ item2->resize(item2->cellWidth() * mGridSpacingX, newSubCellWidth);
+ } else {
+ item2->resize(newSubCellWidth, item2->cellHeight() * mGridSpacingY);
+ }
+ int x,y;
+ gridToContents(item2->cellX(),item2->cellYTop(),x,y);
+ if (mAllDayMode) {
+ y += item2->subCell() * newSubCellWidth;
+ } else {
+ x += item2->subCell() * newSubCellWidth;
+ }
+ moveChild(item2,x,y);
+ //qDebug("setttttt %d %s",maxSubCells, item2->text().latin1() );
+ }
+ }
+ }
+ }
} else {
placeItem->setSubCell(0);
placeItem->setSubCells(1);
@@ -1079,7 +1079,7 @@ void KOAgenda::placeSubCells(KOAgendaItem *placeItem)
conflictItems.append(placeItem);
- // Adjust sub cell geometry of all items
+ // Adjust sub cell geometry of all direct conflict items
for ( item=conflictItems.first(); item != 0;
item=conflictItems.next() ) {